@@ -9,23 +9,13 @@ from pdb import set_trace
 import numpy as np
 
 
-try:
-    from hpogrid.components.defaults import *
-    from hpogrid.utils import helper    
-except:
-    raise ImportError('Cannot import hpogrid module. Try source setupenv first.')
 
-
-kGPUSiteNGPU = {
-    'ANALY_MANC_GPU_TEST': 10, #single queue, no submission parameters, 1 GPU per job
-    'ANALY_QMUL_GPU_TEST': 6, #    GPUNumber=x for now is hardcoded in the dev APF JDL,number of GPUs per job limited by cgroups, K80=2*K40, so total of 6 gpu slots avalable.
-    'ANALY_MWT2_GPU': 8, #single queue, no submission parameters, 1 GPU per job
-    'ANALY_BNL_GPU_ARC': 12, #also shared with Jupyter users who have priority
-    'ANALY_INFN-T1_GPU': 2 #single queue, no submission parameters, 1 GPU per job
-}
+from hpogrid.components.defaults import *
+from hpogrid.utils import helper    
 
 class GridHandler():
     def __init__(self):
+
         # submit grid job via hpogrid executable
         if len(sys.argv) > 1:
             self.run_parser()
@@ -46,17 +36,18 @@ class GridHandler():
             args = parser.parse_args(sys.argv[2:])
         else:
             args = parser.parse_args(sys.argv[1:])
-        self.submit_job(args.proj_name, args.n_jobs, args.site)
+        GridHandler.submit_job(args.proj_name, args.n_jobs, args.site)
+                
+    @staticmethod
+    def submit_job(proj_name, n_jobs=1, site=None):
 
-    def submit_job(self, proj_name, n_jobs=1, site=None):
-
-        grid_config = helper.get_grid_config(proj_name)
+        grid_config = helper.get_project_config(proj_name)['grid_config']
 
         options = {}
 
         options['containerImage'] = grid_config['container']
 
-        options['exec'] = '"python /hpogrid/hpogrid/components/JobHandler.py {}"'.format(proj_name)
+        options['exec'] = '"hpogrid grid_run {}"'.format(proj_name)
 
         if not grid_config['retry']:
             options['disableAutoRetry'] = ''
@@ -64,9 +55,10 @@ class GridHandler():
         extra = {'forceStaged':'', 
                  'useSandbox': '',
                  'noBuild': ''}
+                 
         options.update(extra)
-        options['ctrWorkdir'] = '/hpogrid/project'
-        options['ctrDatadir'] = '/hpogrid/project'
+        options['ctrWorkdir'] = kWorkDir
+        options['ctrDatadir'] = kDataDir
 
         if grid_config['inDS']:
             options['inDS'] = grid_config['inDS']
@@ -79,18 +71,18 @@ class GridHandler():
             site = grid_config['site']
 
         if site is not None:
-            options['site'] = site
-            if 'GPU' in site:
-                options['cmtConfig'] = 'nvidia-gpu'
-            else:
-                options['nCore'] = '8'
+            if not (site == 'ANY'):
+                options['site'] = site
+                if 'GPU' in site:
+                    options['cmtConfig'] = 'nvidia-gpu'
+                else:
+                    options['nCore'] = '8'
+        # options['workDir'] = project_path # does not really work
+        project_path = helper.get_project_path(proj_name)
 
         # construct prun command
         command = ' '.join(["--{} {}".format(key,value) for (key,value) in options.items()])
 
-        # options['workDir'] = project_path # does not really work
-        project_path = helper.get_project_path(proj_name)
-
         # switch to working directory to send files to WNs
         with helper.cd(project_path):
             # submit grid jobs
